<?php
/**
 * Plugin Name: WooCommerce Bundle Pricing
 * Description: Add an extra price option to products in WooCommerce, where the customer can choose between 1 piece or a Bundle.
 * Version: 1.4
 * Author: EasyToolsWP
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// Tilføj ekstra prisfelt til WooCommerce produktindstillinger
function add_bundle_price_field() {
    woocommerce_wp_text_input([
        'id'          => '_bundle_price',
        'label'       => __('Bundle pris', 'woocommerce'),
        'desc_tip'    => 'true',
        'description' => __('Indtast prisen for Bundle-optionen.', 'woocommerce'),
        'type'        => 'number',
        'custom_attributes' => [
            'step' => '0.01',
            'min'  => '0'
        ]
    ]);
    
    woocommerce_wp_text_input([
        'id'          => '_bundle_label',
        'label'       => __('Bundle navn', 'woocommerce'),
        'desc_tip'    => 'true',
        'description' => __('Indtast det navn, der skal vises for Bundle-optionen.', 'woocommerce'),
        'type'        => 'text',
    ]);
}
add_action('woocommerce_product_options_pricing', 'add_bundle_price_field');

// Gem bundle-prisen og navnet når produktet opdateres
function save_bundle_price_field($post_id) {
    $bundle_price = isset($_POST['_bundle_price']) ? sanitize_text_field($_POST['_bundle_price']) : '';
    update_post_meta($post_id, '_bundle_price', $bundle_price);
    
    $bundle_label = isset($_POST['_bundle_label']) ? sanitize_text_field($_POST['_bundle_label']) : 'Bundle';
    update_post_meta($post_id, '_bundle_label', $bundle_label);
}
add_action('woocommerce_process_product_meta', 'save_bundle_price_field');

// Vis valgmulighed som to bokse på produktsiden
function display_bundle_option() {
    global $product;
    
    $bundle_price = get_post_meta($product->get_id(), '_bundle_price', true);
    $bundle_label = get_post_meta($product->get_id(), '_bundle_label', true) ?: 'Bundle';
    if (!$bundle_price) return;
    
    $single_price = $product->get_price();
    
    echo '<div class="bundle-price-option" style="display: flex; gap: 10px; margin-bottom: 15px;">
            <label class="price-option" style="border: 2px solid #ddd; padding: 10px; cursor: pointer;">
                <input type="radio" name="product_price_option" value="single" checked> 1 stk. - <span class="single-price" data-price="' . esc_attr($single_price) . '">' . wc_price($single_price) . '</span>
            </label>
            <label class="price-option" style="border: 2px solid #ddd; padding: 10px; cursor: pointer;">
                <input type="radio" name="product_price_option" value="bundle"> ' . esc_html($bundle_label) . ' - <span class="bundle-price" data-price="' . esc_attr($bundle_price) . '">' . wc_price($bundle_price) . '</span>
            </label>
          </div>
          <script>
            document.addEventListener("DOMContentLoaded", function() {
                let qtyInput = document.querySelector(".input-text.qty.text");
                let bundlePrice = document.querySelector(".bundle-price");
                if (qtyInput && bundlePrice) {
                    qtyInput.style.display = "none";
                }
                let priceContainer = document.querySelector(".price .woocommerce-Price-amount");
                let priceOptions = document.querySelectorAll(".bundle-price-option input[type=radio]");
                
                priceOptions.forEach(option => {
                    option.addEventListener("change", function() {
                        let selectedOption = this.value;
                        let newPrice = selectedOption === "bundle" 
                            ? document.querySelector(".bundle-price").getAttribute("data-price") 
                            : document.querySelector(".single-price").getAttribute("data-price");
                        
                        if (priceContainer) {
                            priceContainer.innerHTML = newPrice + " kr";
                        }
                    });
                });
            });
          </script>';
}
add_action('woocommerce_before_add_to_cart_button', 'display_bundle_option');

// Juster prisen baseret på valg
function add_bundle_option_to_cart_item_data($cart_item_data, $product_id) {
    if (isset($_POST['product_price_option'])) {
        $cart_item_data['product_price_option'] = sanitize_text_field($_POST['product_price_option']);
        $cart_item_data['unique_key'] = md5(microtime().rand());
    }
    return $cart_item_data;
}
add_filter('woocommerce_add_cart_item_data', 'add_bundle_option_to_cart_item_data', 10, 2);

// Opdater prisen i kurven
function update_cart_price($cart) {
    if (is_admin() && !defined('DOING_AJAX')) return;

    foreach ($cart->get_cart() as $cart_item) {
        if (isset($cart_item['product_price_option'])) {
            $product_id = $cart_item['product_id'];
            $bundle_price = get_post_meta($product_id, '_bundle_price', true);
            $single_price = get_post_meta($product_id, '_price', true);
            $bundle_label = get_post_meta($product_id, '_bundle_label', true) ?: 'Bundle';

            if ($cart_item['product_price_option'] == 'bundle' && $bundle_price) {
                $cart_item['data']->set_price((float) $bundle_price);
                if (strpos($cart_item['data']->get_name(), '(' . $bundle_label . ')') === false) {
                    $cart_item['data']->set_name($cart_item['data']->get_name() . ' (' . esc_html($bundle_label) . ')');
                }
            } else {
                $cart_item['data']->set_price((float) $single_price);
                if (strpos($cart_item['data']->get_name(), '(1 stk.)') === false) {
                    $cart_item['data']->set_name($cart_item['data']->get_name() . ' (1 stk.)');
                }
            }
        }
    }
}
add_action('woocommerce_before_calculate_totals', 'update_cart_price');
